==> plantuml-libs-7.1.0.tgz: package/distribution/fontawesome-6/Solid/MagnifyingGlassLocation.md <==
# MagnifyingGlassLocation


```text
fontawesome-6/Solid/MagnifyingGlassLocation
```

```text
include('fontawesome-6/Solid/MagnifyingGlassLocation')
```



| Illustration | MagnifyingGlassLocation |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/MagnifyingGlassLocation.png) | ![illustration for MagnifyingGlassLocation](../../fontawesome-6/Solid/MagnifyingGlassLocation.Local.png) |




## MagnifyingGlassLocation

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element MagnifyingGlassLocation
include('fontawesome-6/Solid/MagnifyingGlassLocation')

' renders the element
MagnifyingGlassLocation('MagnifyingGlassLocation', 'Magnifying Glass Location', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element MagnifyingGlassLocation
include('fontawesome-6/Solid/MagnifyingGlassLocation')

' renders the element
MagnifyingGlassLocation('MagnifyingGlassLocation', 'Magnifying Glass Location', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/fontawesome-6/Solid/MagnifyingGlassLocation.md <==
# MagnifyingGlassLocation


```text
fontawesome-6/Solid/MagnifyingGlassLocation
```

```text
include('fontawesome-6/Solid/MagnifyingGlassLocation')
```



| Illustration | MagnifyingGlassLocation |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/MagnifyingGlassLocation.png) | ![illustration for MagnifyingGlassLocation](../../fontawesome-6/Solid/MagnifyingGlassLocation.Local.png) |




## MagnifyingGlassLocation

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element MagnifyingGlassLocation
include('fontawesome-6/Solid/MagnifyingGlassLocation')

' renders the element
MagnifyingGlassLocation('MagnifyingGlassLocation', 'Magnifying Glass Location', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element MagnifyingGlassLocation
include('fontawesome-6/Solid/MagnifyingGlassLocation')

' renders the element
MagnifyingGlassLocation('MagnifyingGlassLocation', 'Magnifying Glass Location', 'an optional tech label', 'an optional description')
@enduml
```
